@@ -11,7 +11,7 @@ venue_dir = os.path.dirname(settings_dir)
 DBENGINE = 'django.db.backends.sqlite3'
 DBHOST = '127.0.0.1'
 DBPORT = ''
-DBUSER = ''
+DBUSER = 'backstage'
 DBPASS = ''
 DBNAME = os.path.join(venue_dir, 'db/django_backstage.sq3')
 
